#
# spec file for package python-geopy
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%{?sle15_python_module_pythons}
Name:           python-geopy
Version:        2.3.0
Release:        1.6
License:        MIT
Summary:        Python Geocoding Toolbox
Url:            https://github.com/geopy/geopy
Group:          Development/Languages/Python
Source:         https://github.com/geopy/geopy/archive/%{version}.tar.gz#/geopy-%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module setuptools}
# SECTION test requirements
BuildRequires:  %{python_module async_generator}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module geographiclib >= 1.49}
BuildRequires:  %{python_module pytest >= 3.10}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module xml}
# /SECTION
BuildRequires:  fdupes
Requires:       python-geographiclib >= 1.49
Recommends:     python-pytz
Recommends:     python-xml
%ifpython2
Requires:       python-statistics
%endif
BuildArch:      noarch

%python_subpackages

%description
Geopy can determine the coordinates of addresses, cities, countries,
and landmarks using third-party geocoders and other data sources such
as wikis.

Geopy currently includes support for six geocoders: Google Maps, Yahoo! Maps, Windows
Local Live (Virtual Earth), geocoder.us, GeoNames, MediaWiki pages (with the GIS
extension), and Semantic MediaWiki pages.

%prep
%setup -q -n geopy-%{version}


# Online services are not available
rm \
  test/geocoders/arcgis.py \
  test/geocoders/banfrance.py \
  test/geocoders/databc.py \
  test/geocoders/geonames.py \
  test/geocoders/googlev3.py \
  test/geocoders/ignfrance.py \
  test/geocoders/nominatim.py \
  test/geocoders/openmapquest.py \
  test/geocoders/photon.py \
  test/geocoders/pickpoint.py \
  test/geocoders/yandex.py

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pyunittest discover -v

%files %{python_files}
%doc AUTHORS README.rst docs/changelog_09x.rst docs/changelog_1xx.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 2.3.0
  New Features:
  * .MapBox: add referer param to allow restricted api_keys.
  * Contributed by Dennis Stritzke. (#501)
  * .MapBox: add language param to geocode.
  * Contributed by Dennis Stritzke. (#503)
  * .Distance: add floor division + right multiplication
  * operators. (#485)
  * .Distance: make hashable. (#485)
  * .Nominatim: add namedetails param to reverse. (#525)
  * .Pelias: add countries param to geocode. (#504)
  * .GoogleV3: pass the original error_message to exceptions.
  * (#398)
  Packaging Changes
  * Drop support for Python 3.5 and 3.6.
  * Add support for Python 3.10 and 3.11.
  * Relax geographiclib upper version constraint to allow 2.x.
  * Contributed by David Hotham. (#520)
  * Raise geographiclib lower version constraint to 1.52 to fix possible
  * ValueError in .distance.geodesic due to
  * the floating point inaccuracy. (#466)
  * Move static metadata from setup.py to setup.cfg.
  Deprecations
  * .Pelias: deprecate country_bias param, use countries
  * instead. (#504)
  * .IGNFrance: authentication is no longer accepted by the API,
  * so passing any credentials to the geocoder class has been deprecated.
  * These arguments should be removed. (#496)
  Bugfixes
  * Fix possible TypeError thrown by .RequestsAdapter
  * on destruction. Contributed by Philip Kahn. (#488)
  * .ArcGIS: get address from LongLabel if Address is empty.
  * All geocoders: fix unexpected scientific point format for coordinates
  * near zero in reverse geocoding. (#511)
  * .BANFrance: fix broken reverse (it looks like their API has
  * changed in a backwards-incompatible way: the lng query arg has
  * been renamed to lon).
  * .IGNFrance: fix broken geocoder due to removal of
  * authentication in their API. (#496)
  Docs Improvements
  * Add url to the GIS Stack Exchange geopy tag.
  * Contributed by Taras Dubrava. (#516).
  * .GeocodeEarth: add docs and pricing urls.
  * Contributed by Julian Simioni. (#505).
- Use sle15_python_module_pythons
* Fri Nov  4 2022 pgajdos@suse.com
- python-six not required
* Mon Mar 21 2022 pgajdos@suse.com
- version update to 2.2.0
  New Features
  ~~~~~~~~~~~
  - :class:`.OpenCage`: added ``annotations`` param.
    Contributed by mtmail. (:issue:`464`)
  - :class:`.Photon`: added ``bbox`` param.
    Contributed by Holger Bruch. (:issue:`472`)
  - New geocoder: :class:`.Geocodio`.
    Contributed by Jon Duckworth. (:issue:`468`)
  - New geocoder: :class:`.HereV7`.
    Contributed by Pratheek Rebala. (:issue:`433`)
  - New geocoder: :class:`.What3WordsV3`.
    Contributed by Saïd Tezel. (:issue:`444`)
  - New error class: :class:`.exc.GeocoderRateLimited`. This error extends
    :class:`.exc.GeocoderQuotaExceeded` and is now raised instead of it
    for HTTP 422 error code. (:issue:`479`)
  - :class:`.AdapterHTTPError`: added ``headers`` attribute. (:issue:`479`)
  Breaking Changes
  ~~~~~~~~~~~~~~~
  - Removed GeocodeFarm class: the service is very unstable. (:issue:`445`)
  Deprecations
  ~~~~~~~~~~~
  - :class:`.GoogleV3` has been moved from ``geopy.geocoders.googlev3`` module
    to ``geopy.geocoders.google``. The old module is still present for
    backwards compatibility, but it will be removed in geopy 3. (:issue:`483`)
  Bugfixes
  ~~~~~~~
  - :class:`.OpenCage`: improved error handling by using the default errors map
    (e.g. to raise :class:`.exc.GeocoderQuotaExceeded` instead of
    :class:`.exc.GeocoderQueryError` for HTTP 402 error). (:issue:`479`)
* Tue May 25 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Sun Dec 27 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 2.1.0 version
  + New Features
  - Add support for leading plus sign in the .Point constructor.
  - Contributed by Azimjon Pulatov. (#448)
  + Breaking Changes
  - .GoogleV3: change missing api_key warning to an error. (#450)
  + Bugfixes
  - Fixed an undocumented breaking change in geopy 2.0.0, where
    the .Distance class has become abstract, thus it could
    no longer be used for unit conversions. (#435)
  - .Photon incorrectly treated 0.0 coordinate as an empty response.
    Contributed by Mateusz Konieczny. (#439)
  - .Nominatim: fix TypeError on empty reverse result. (#455)
  + Docs Improvements
  - Add Python 3.9 to the list of supported versions.
  - .Bing: change postalcode to postalCode.
    Contributed by zhongjun-ma. (#424)
  - .Nominatim: better describe what is returned in addressdetails.
    Contributed by Mateusz Konieczny. (#429)
  - .Nominatim: better describe viewbox param behavior.
    Contributed by Hannes. (#454)
  - .Yandex: remove attention block about requiring an API key.
- Update to 2.0.0 version
  geopy 2.0 is a major release with lots of cleanup and inner refactorings.
  The public interface of the library is mostly the same, and the set
  of supported geocoders didn't change.
  If you have checked your code on the latest 1.x release with enabled
  warnings (i.e. with -Wd key of the python command) and fixed
  all of them, then it should be safe to upgrade.
  see all changes at https://github.com/geopy/geopy/releases/tag/2.0.0
- Changes from previous version
  1.23.0 https://github.com/geopy/geopy/releases/tag/1.23.0
  1.22.0 https://github.com/geopy/geopy/releases/tag/1.22.0
  1.21.0 https://github.com/geopy/geopy/releases/tag/1.21.0
  1.20.0 https://github.com/geopy/geopy/releases/tag/1.20.0
  1.19.0 https://github.com/geopy/geopy/releases/tag/1.19.0
- Packaging changes dropped support for Python 2.7 and 3.4. as version
  2.x has remove it.
* Tue Oct 13 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Only buildRequire python2-* when also using python, aka python2.
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Mon Mar 25 2019 John Vandenberg <jayvdb@gmail.com>
- Update URL to https://github.com/geopy/geopy
- Convert to single spec
- Activate test suite
- Remove unnecessary build dependency on python-devel
- Use %%license
- Added changelog to %%doc
- update to v1.18.1
  - Geocoders dot_us, navidata and placefinder removed
  - Many new geocoders added
  - See changelog_1xx.rst for more details
* Thu Feb 18 2016 eshmarnev@suse.com
- update to version 1.11.0:
  * ADDED: Photon geocoder.
  * ADDED: Bing supports structured query parameters.
  * CHANGED: Geocoders send a User-Agent header, which by default is geopy/1.11.0.
  * FIXED: Index out of range error with no results using Yandex.
  * FIXED: Nominatim was incorrectly sending view_box when not requested, and formatting it incorrectly.
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 1.10.0:
  * CHANGED: GeocodeFarm now uses version 3 of the service’s API,
    which allows use by unauthenticated users, multiple results,
    and SSL/TLS. You may need to obtain a new API key from
    GeocodeFarm, or use None for their free tier. Contributed by
    Eric Palakovich Carr.
  * ADDED: DataBC geocoder for use with the British Columbia
    government’s DataBC service. Contributed by Benjamin
    Trigona-Harany.
  * ADDED: Placefinder’s geocode method now requests a timezone if
    the with_timezone parameter is true. Contributed by willr.
  * FIXED: Nominatim specifies a viewbox parameter rather than the
    apparently deprecated view_box.
- additional changes from version 1.9.1:
  * FIXED: Fix support for GoogleV3 bounds parameter. Contributed
    by Benjamin Trigona-Harany.
- additional changes from version 1.9.0:
  * CHANGED: MapQuest geocoder removed as the API it uses is now
    only available to enterprise accounts. OpenMapQuest is a
    replacement for Nominatim-sourced data.
  * CHANGED: Nominatim now uses HTTPS by default and accepts a
    scheme argument. Contributed by srounet.
  * ADDED: Nominatim now accepts a domain argument, which allows
    using a different server than nominatim.openstreetmap.org.
    Contributed by srounet.
  * FIXED: Bing was not accessible from get_geocoder_for_service.
    Contributed by Adrián López.
- additional changes from version 1.8.1:
  * FIXED: GoogleV3 geocoder did not send API keys for reverse and
    timezone methods.
- additional changes from version 1.8.0:
  * ADDED: NaviData geocoder added. Contributed by NaviData.
  * CHANGED: LiveAddress now requires HTTPS connections. If you set
    scheme to be http, rather than the default https, you will now
    receive a ConfigurationError.
- additional changes from version 1.7.1:
  * FIXED: IGN France geocoder’s address formatting better handles
    results that do not have a building number. Contributed by
    Thomas Gratier.
- additional changes from version 1.7.0:
  * ADDED: IGN France geocoder. Contributed by Thomas Gratier.
  * FIXED: Bing checks the response body for error codes.
- additional changes from version 1.6.1:
  * FIXED: What3Words validation loosened. Contributed by
    spatialbitz.
  * FIXED: Point.format() includes altitude.
- additional changes from version 1.6.0:
  * ADDED: Python 3.2 and PyPy3 compatibility. Contributed by Mike
    Toews.
- additional changes from version 1.5.0:
  * ADDED: Yandex geocoder added. Contributed by htch.
  * ADDED: What3Words geocoder added. Contributed by spatialbitz.
  * FIXED: LiveAddress geocoder made compatible with a change in
    the service’s authentication. An auth_id parameter was added to
    the geocoder’s initialization. Contributed by Arsen Mamikonyan.
- additional changes from version 1.4.0:
  * ADDED: Mapquest.reverse() method added. Contributed by Dody
    Suria Wijaya.
  * ADDED: Bing’s geocoder now accepts the optional arguments
    “culture”, “includeNeighborhood”, and “include”. Contributed by
    oskholl.
- additional changes from version 1.3.0:
  * ADDED: Nominatim.geocode() accepts a geometry argument for
    retrieving wkt, svg, kml, or geojson formatted geometries in
    results. Contributed by spatialbitz.
- additional changes from version 1.2.0:
  * ADDED: GeoNames.reverse() added. Contributed by Emile Aben.
  * ADDED: GoogleV3.timezone() added. This returns a pytz object
    giving the timezone in effect for a given location at a time
    (defaulting to now).
- additional changes from version 1.1.5:
  * FIXED: YahooPlaceFinder is now compatible with the older
    requests_oauthlib version 0.4.0.
- additional changes from version 1.1.4:
  * FIXED: Point.format() seconds precision in Python 3.
- additional changes from version 1.1.3:
  * FIXED: Fix OpenCage AttributeError on empty result. Contributed
    by IsaacHaze.
- additional changes from version 1.1.2:
  * FIXED: Update Point __repr__ method to format _items properly.
    Contributed by TristanH.
- additional changes from version 1.1.1:
  * FIXED: Python 3 compatibility.
- additional changes from version 1.1.0:
  * ADDED: OpenCage geocoder added. Contributed by Demeter Sztanko.
  * ADDED: geopy.geocoders.get_geocoder_for_service allows library
    authors to dynamically get a geocoder.
  * FIXED: YahooPlacefinder bugs causing geocoding failure.
  * FIXED: LiveAddress API URL updated.
  * FIXED: Location.__repr__ unicode encode error in Python 2.7.
  * CHANGED: geopy.geocoders modules now strictly declare their
    exports.
- additional changes from version 1.0.1:
  * FIXED: The Baidu Maps geocoder’s _check_status method used a
    Python 2-specific print statement.
- additional changes from version 1.0.0:
  * ADDED: Baidu Maps geocoder added. Contributed by Risent.
  * ADDED: Nominatim geocoder now supports structured queries.
    Contributed by kpanic.
  * ADDED: Nominatim geocoder now supports a language parameter.
    Contributed by Benjamin Henne.
  * CHANGED: GoogleV3’s geocode and reverse methods have different
    orders for keyword argument parameters. Geocoders are now
    standardized on (query, exactly_one, timeout, ...).
  * FIXED: Removed rounding of minutes which was causing a
    formatted point to always have zero seconds. Contributed by
    Jonathan Batchelor.
- additional changes from version 0.99:
  * ADDED: GeocodeFarm geocoder added with support for geocoding
    and reverse geocoding. Contributed by Eric Palakovich Carr.
- additional changes from version 0.98.3:
  * ADDED: Queries are encoded as unicode in Python 2.7 by the
    geocoder. Contributed by Rocky Meza.
  * FIXED: YahooPlaceFinder count parameter fixed.
  * FIXED: Point.__repr__ fixed. Contributed by Paweł Mandera.
- additional changes from version 0.98.2:
  * ADDED: GoogleV3 now accepts an api_key parameter. Contributed
    by Andrea Tosatto.
  * CHANGED: GoogleV3’s deprecated protocol argument has been
    removed.
- additional changes from version 0.98.1:
  * FIXED: Mapquest geocoder did not use format_string in the
    creation of its queries. Contributed by Danny Finkelstein.
  * FIXED: Geocoders incorrectly raised a GeocoderTimedOut
    exception for all SSLError exceptions. Contributed by David
    Gilman.
- additional changes from version 0.98:
  * CHANGED: Geocoders’ geocode and reverse method return types
    have changed from None, a tuple, or a list of tuples, to None,
    a geopy.Location object, or a list of geopy.Location objects.
- additional changes from version 0.97.1:
  * FIXED:YahooPlaceFinder geocoder authentication and response
    parsing fixed. Contributed by petergx.
  * ADDED: GoogleV3 geocoding now supports a components parameter,
    which is a filter for location criteria such as administrative
    area, country, etc. Contributed by crccheck.
- additional changes from version 0.97:
  * CHANGED: SSL connections are used by default for services with
    support. These geocoders accept a new ‘scheme’ argument in
    their init, which may be ‘https’ or ‘http’. Users desiring
    unencrypted connections must now specify ‘http’. Note that SSL
    connections’ certificates are not verified.
  * CHANGED: Geocoders accept a timeout argument which specifies
    the number of seconds to wait before raising a GeocoderTimedOut
    exception. This can be specified in the init, or specified
    one-off in each geocode or reverse call. There is now a default
    of 1 second.
  * CHANGED: geopy now supports Python 2 and Python 3 on a single
    codebase. Support for Python 2.5 is also dropped.
  * CHANGED: GoogleV3’s protocol argument is deprecated in favor of
    scheme.
  * ADDED: ESRI’s ArcGIS geocoder implemented. Contributed by Arsen
    Mamikonyan.
  * ADDED: Geocoders accept a proxies argument which specifies a
    proxy to route its geocoder requests through. It uses urllib,
    and accepts proxies in the form of a dictionary of {scheme:
    proxy address}, e.g., {“https”: “192.0.2.0”}. This was present
    but undocumented in 0.96.
  * ADDED: Geocoders check a new method,
    _geocoder_exception_handler, if defined, when the HTTP call to
    the geocoder’s service raises an exception. See LiveStreets for
    an example. Users can define or override this method.
  * ADDED: LiveStreets throws a GeocoderQuotaExceeded exception
    when appropriate.
  * ADDED: Point can parse a greater variety of coordinate strings.
    Contributed by nucflash.
  * FIXED: GeocodersDotUS now authenticates with an Authorization
    HTTP header. Contributed by Arsen Mamikonyan.
  * REMOVED: MediaWiki and SemanticMediaWiki geocoders removed.
  * REMOVED: Geohash module has been removed.
- additional changes from version 0.96.3:
  * ADDED: Documentation warning that the Vincenty distance
    implementation fails to converge for some valid points.
    Reported by mkeller-upb.
  * FIXED: Geocoder proxying fixed. Contributed by Marc-Olivier
    Titeux.
- limit build to python 2.7
- remove RELEASES from package files: not provided anymore
* Wed Dec 11 2013 p.drouand@gmail.com
- Update to version 0.96.2
  + fix : MANIFEST.in should not use `exclude`.
- Changes from 0.96.1
  + fix : GoogleV3 returns `None` when the service returns an error
    status of `ZERO_RESULTS`.
- Changes from 0.96.0
  + GoogleV3's reverse geocoder now returns one result by default. Set
    `exactly_one` to False for a list.
  + GoogleV3 returns new exception types:
    `geopy.geocoders.base.GQueryError` -> `geopy.exc.GeocoderQueryError`
    `geopy.geocoders.base.GeocoderResultError` -> `geopy.exc.GeocoderQueryError`
    `geopy.geocoders.base.GTooManyQueriesError` -> `geopy.exc.GeocoderQuotaExceeded`
  + OpenStreetMap Nominatim geocoder implemented.
  + Yahoo! BOSS Geo PlaceFinder geocoder implemented.
  + SmartyStreets LiveAddress geocoder implemented.
  + GeoNames geocoder is implements GeoNames' new username
    requirement and `api.geonames.org` endpoint.
  + Bing geocoder supports `user_location` (`Point`) parameter. Bing will
    prefer results near the coordinates of `user_location`.
  + `GoogleV3.geocode_first()` no longer throws exception on multiple
    results.
  + Unnecessary coercing to UTF-8 on Py3k.
  +`format_degrees` now rounds minutes properly.
  + No longer warn if the optional dependency `BeautifulSoup` is
    not present.
  + Miscellaneous inconsistent behavior and errors in geolocating.
  + Google V2 geocoder has been removed as its API was shutdown.
- Changes from 0.95.1
  + Fix #12, where `DeprecationWarning` was showing for GoogleV2 even if
    it wasn't being used (due to `geopy.geocoders` importing it).
  + `GoogleV3.geocode` "address" kwarg renamed to "string" to match
    `Google.geocode` to make updating easier.
  + Geocoders now properly handle Unicode objects as input (previously
    would fail on non-ASCII characters due to wanting UTF-8 strings).
- Changes from 0.95
  + Google Geocoding API V3 support. "google.Google()" should be
    replaced by "googlev3.GoogleV3()", with no `api_key`.
    Please see http://goo.gl/somDT for valid arguments.
  + setup.py updated to now automatically support Python 3+
    (via 2to3 auto-compile option).
- Package LICENSE, README and RELEASES in documentation directory
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Mar 13 2012 alexandre@exatati.com.br
- Update to 0.94.2:
  ADDED:   MANIFEST.in so that LICENSE file gets included in dist
    packages (per req by Debian Python Module Team)
  UPDATED: Yahoo geocoder uses new PlaceFinder API instead of
    outdated MapsService V1 API.
* Wed Sep 21 2011 saschpe@suse.de
- Spec file cleanup:
  * Removed %%clean section (not needed anymore)
  * Removed CFLAGS (not a C extension)
* Thu Mar 24 2011 alexandre@exatati.com.br
- Update to 0.94.1;
- Regenerated spec file with py2pack.
* Tue Mar  9 2010 alexandre@exatati.com.br
- Update to 0.94;
- Building as noarch for openSUSE >= 11.2.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (0.93) for openSUSE.
